@@ -2,18 +2,20 @@ package resources
 
 import (
 	"fmt"
+	"strings"
+	"time"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
 	"github.com/rebuy-de/aws-nuke/pkg/types"
 	"github.com/sirupsen/logrus"
-	"strings"
-	"time"
 )
 
 func init() {
-	register("CloudFormationStackSet", ListCloudFormationStackSets)
+	register("CloudFormationStackSet", ListCloudFormationStackSets,
+		mapCloudControl("AWS::CloudFormation::StackSet"))
 }
 
 func ListCloudFormationStackSets(sess *session.Session) ([]Resource, error) {
