@@ -8,9 +8,11 @@ import (
 )
 
 type EC2Image struct {
-	svc  *ec2.EC2
-	id   string
-	tags []*ec2.Tag
+	svc          *ec2.EC2
+	creationDate string
+	id           string
+	name         string
+	tags         []*ec2.Tag
 }
 
 func init() {
@@ -32,9 +34,11 @@ func ListEC2Images(sess *session.Session) ([]Resource, error) {
 	resources := make([]Resource, 0)
 	for _, out := range resp.Images {
 		resources = append(resources, &EC2Image{
-			svc:  svc,
-			id:   *out.ImageId,
-			tags: out.Tags,
+			svc:          svc,
+			creationDate: *out.CreationDate,
+			id:           *out.ImageId,
+			name:         *out.Name,
+			tags:         out.Tags,
 		})
 	}
 
@@ -50,6 +54,10 @@ func (e *EC2Image) Remove() error {
 
 func (e *EC2Image) Properties() types.Properties {
 	properties := types.NewProperties()
+
+	properties.Set("CreationDate", e.creationDate)
+	properties.Set("Name", e.name)
+
 	for _, tagValue := range e.tags {
 		properties.SetTag(tagValue.Key, tagValue.Value)
 	}
