@@ -3,11 +3,13 @@ package resources
 import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/elasticsearchservice"
+	"github.com/rebuy-de/aws-nuke/pkg/types"
 )
 
 type ESDomain struct {
 	svc        *elasticsearchservice.ElasticsearchService
 	domainName *string
+	tagList    []*elasticsearchservice.Tag
 }
 
 func init() {
@@ -25,9 +27,19 @@ func ListESDomains(sess *session.Session) ([]Resource, error) {
 
 	resources := make([]Resource, 0)
 	for _, domain := range resp.DomainNames {
+		dedo, err := svc.DescribeElasticsearchDomain(
+			&elasticsearchservice.DescribeElasticsearchDomainInput{DomainName: domain.DomainName})
+		if err != nil {
+			return nil, err
+		}
+		lto, err := svc.ListTags(&elasticsearchservice.ListTagsInput{ARN: dedo.DomainStatus.ARN})
+		if err != nil {
+			return nil, err
+		}
 		resources = append(resources, &ESDomain{
 			svc:        svc,
 			domainName: domain.DomainName,
+			tagList:    lto.TagList,
 		})
 	}
 
@@ -43,6 +55,14 @@ func (f *ESDomain) Remove() error {
 	return err
 }
 
+func (f *ESDomain) Properties() types.Properties {
+	properties := types.NewProperties()
+	for _, t := range f.tagList {
+		properties.SetTag(t.Key, t.Value)
+	}
+	return properties
+}
+
 func (f *ESDomain) String() string {
 	return *f.domainName
 }
