@@ -3,11 +3,14 @@ package resources
 import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
+	"github.com/rebuy-de/aws-nuke/pkg/types"
 )
 
 type IAMGroup struct {
 	svc  *iam.IAM
+	id   string
 	name string
+	path string
 }
 
 func init() {
@@ -26,7 +29,9 @@ func ListIAMGroups(sess *session.Session) ([]Resource, error) {
 	for _, out := range resp.Groups {
 		resources = append(resources, &IAMGroup{
 			svc:  svc,
+			id:   *out.GroupId,
 			name: *out.GroupName,
+			path: *out.Path,
 		})
 	}
 
@@ -47,3 +52,10 @@ func (e *IAMGroup) Remove() error {
 func (e *IAMGroup) String() string {
 	return e.name
 }
+
+func (e *IAMGroup) Properties() types.Properties {
+	return types.NewProperties().
+		Set("Name", e.name).
+		Set("Path", e.path).
+		Set("ID", e.id)
+}
