@@ -4,18 +4,28 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
 	"github.com/rebuy-de/aws-nuke/pkg/types"
+	"github.com/sirupsen/logrus"
 )
 
 type IAMInstanceProfile struct {
-	svc  *iam.IAM
-	name string
-	tags []*iam.Tag
+	svc     *iam.IAM
+	profile *iam.InstanceProfile
+	name    string
+	path    string
 }
 
 func init() {
 	register("IAMInstanceProfile", ListIAMInstanceProfiles)
 }
 
+func GetIAMInstanceProfile(svc *iam.IAM, instanceProfileName *string) (*iam.InstanceProfile, error) {
+	params := &iam.GetInstanceProfileInput{
+		InstanceProfileName: instanceProfileName,
+	}
+	resp, err := svc.GetInstanceProfile(params)
+	return resp.InstanceProfile, err
+}
+
 func ListIAMInstanceProfiles(sess *session.Session) ([]Resource, error) {
 	svc := iam.New(sess)
 	params := &iam.ListInstanceProfilesInput{}
@@ -28,10 +38,20 @@ func ListIAMInstanceProfiles(sess *session.Session) ([]Resource, error) {
 		}
 
 		for _, out := range resp.InstanceProfiles {
+			profile, err := GetIAMInstanceProfile(svc, out.InstanceProfileName)
+			if err != nil {
+				logrus.
+					WithError(err).
+					WithField("instanceProfileName", *out.InstanceProfileName).
+					Error("Failed to get listed instance profile")
+				continue
+			}
+
 			resources = append(resources, &IAMInstanceProfile{
-				svc:  svc,
-				name: *out.InstanceProfileName,
-				tags: out.Tags,
+				svc:     svc,
+				name:    *out.InstanceProfileName,
+				path:    *profile.Path,
+				profile: profile,
 			})
 		}
 
@@ -62,11 +82,14 @@ func (e *IAMInstanceProfile) String() string {
 
 func (e *IAMInstanceProfile) Properties() types.Properties {
 	properties := types.NewProperties()
-	properties.Set("Name", e.name)
 
-	for _, tag := range e.tags {
-		properties.SetTag(tag.Key, tag.Value)
+	for _, tagValue := range e.profile.Tags {
+		properties.SetTag(tagValue.Key, tagValue.Value)
 	}
 
+	properties.
+		Set("Name", e.name).
+		Set("Path", e.path)
+
 	return properties
 }
