@@ -2,6 +2,7 @@ package resources
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/rebuy-de/aws-nuke/pkg/config"
@@ -38,28 +39,54 @@ type FeatureFlagGetter interface {
 
 var resourceListers = make(ResourceListers)
 
-func register(name string, lister ResourceLister) {
+func register(name string, lister ResourceLister, opts ...registerOption) {
 	_, exists := resourceListers[name]
 	if exists {
 		panic(fmt.Sprintf("a resource with the name %s already exists", name))
 	}
 
 	resourceListers[name] = lister
+
+	for _, opt := range opts {
+		opt(name, lister)
+	}
 }
 
-func GetListers() ResourceListers {
-	return resourceListers
+var cloudControlMapping = map[string]string{}
+
+func GetCloudControlMapping() map[string]string {
+	return cloudControlMapping
+}
+
+type registerOption func(name string, lister ResourceLister)
+
+func mapCloudControl(typeName string) registerOption {
+	return func(name string, lister ResourceLister) {
+		_, exists := cloudControlMapping[typeName]
+		if exists {
+			panic(fmt.Sprintf("a cloud control mapping for %s already exists", typeName))
+		}
+
+		cloudControlMapping[typeName] = name
+	}
 }
 
 func GetLister(name string) ResourceLister {
+	if strings.HasPrefix(name, "AWS::") {
+		return NewListCloudControlResource(name)
+	}
 	return resourceListers[name]
 }
 
 func GetListerNames() []string {
 	names := []string{}
-	for resourceType, _ := range GetListers() {
+	for resourceType := range resourceListers {
 		names = append(names, resourceType)
 	}
 
 	return names
 }
+
+func registerCloudControl(typeName string) {
+	register(typeName, NewListCloudControlResource(typeName), mapCloudControl(typeName))
+}
